cat — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# cat

pyprocar.scripts.cat(inFiles: List[str] | None = None, outFile: str = 'PROCAR_merged', gz: bool = False, mergeparallel: bool = False, fixformat: bool = False, nspin: int = 1, abinit_output: str | None = None)

  This module concatenates multiple PROCARs. If a list of input PROCAR files is not provided it will merge all the PROCAR_* files in the directory.

  Parameters:

    - inFiles (List[str], optional) – A list of PROCAR files to concatenate, by default None

    - outFile (str, optional) – String for the output, by default “PROCAR_merged”

    - gz (bool, optional) – Boolean if output should be compressed to .gz file, by default False

    - mergeparallel (bool, optional) – Boolean for merging PROCARs generated from parallel Abinit calculations., by default False

    - fixformat (bool, optional) – Boolean to fix formatting issues in the Abinit PROCAR file., by default False

    - nspin (int, optional) – To detect if the calculation is spin-colinear it checks for the nsppol flag in the Abinit output file as set in abinit_output. If not present, set nspin., by default 1

    - abinit_output (str, optional) – The abinit output file, by default None